parse

Function parse 

pub fn parse(
    s: &str,
) -> Result<Vec<BorrowedFormatItem<'_>>, InvalidFormatDescription>
👎Deprecated since 0.3.48:

use parse_borrowed with the appropriate version for clarity

Available on (crate features formatting or parsing) and crate feature alloc only.
Parse a sequence of items from the format description.

The syntax for the format description can be found in the book.

This function exists for backward compatibility reasons. It is equivalent to calling parse_borrowed::<1>(s). It is recommended to use version 3, not version 1.