struct Unused<T>(PhantomData<T>);Available on crate feature
alloc and (crate features formatting or parsing) only.Expand description
A value that may be used in the future, but currently is not.
This struct exists so that data can semantically be passed around without actually passing it around. This way the data still exists if it is needed in the future.
Tuple Fields
0: PhantomData<T>Auto Trait Implementations
impl<T> Freeze for Unused<T>where
PhantomData<T>: Freeze,
impl<T> RefUnwindSafe for Unused<T>where
PhantomData<T>: RefUnwindSafe,
impl<T> Send for Unused<T>where
PhantomData<T>: Send,
impl<T> Sync for Unused<T>where
PhantomData<T>: Sync,
impl<T> Unpin for Unused<T>where
PhantomData<T>: Unpin,
impl<T> UnsafeUnpin for Unused<T>where
PhantomData<T>: UnsafeUnpin,
impl<T> UnwindSafe for Unused<T>where
PhantomData<T>: UnwindSafe,